==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/REGIONHISTORICALTEMPERATUREID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour REGIONHISTORICALTEMPERATUREID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="REGIONHISTORICALTEMPERATUREID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REGIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DAYOFYEAR"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "REGIONHISTORICALTEMPERATUREID_Type", propOrder = {
    "regionid",
    "dayofyear"
})
public class REGIONHISTORICALTEMPERATUREID_Type {

    @XmlElement(name = "REGIONID", required = true)
    protected REGIONID_Type regionid;
    @XmlElement(name = "DAYOFYEAR")
    protected long dayofyear;

    /**
     * Obtient la valeur de la propriété regionid.
     * 
     * @return
     *     possible object is
     *     {@link REGIONID_Type }
     *     
     */
    public REGIONID_Type getREGIONID() {
        return regionid;
    }

    /**
     * Définit la valeur de la propriété regionid.
     * 
     * @param value
     *     allowed object is
     *     {@link REGIONID_Type }
     *     
     */
    public void setREGIONID(REGIONID_Type value) {
        this.regionid = value;
    }

    /**
     * Obtient la valeur de la propriété dayofyear.
     * 
     */
    public long getDAYOFYEAR() {
        return dayofyear;
    }

    /**
     * Définit la valeur de la propriété dayofyear.
     * 
     */
    public void setDAYOFYEAR(long value) {
        this.dayofyear = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/REGIONHISTORICALTEMPERATUREID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for REGIONHISTORICALTEMPERATUREID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="REGIONHISTORICALTEMPERATUREID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REGIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DAYOFYEAR"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "REGIONHISTORICALTEMPERATUREID_Type", propOrder = {
    "regionid",
    "dayofyear"
})
public class REGIONHISTORICALTEMPERATUREID_Type {

    @XmlElement(name = "REGIONID", required = true)
    protected REGIONID_Type regionid;
    @XmlElement(name = "DAYOFYEAR")
    protected long dayofyear;

    /**
     * Gets the value of the regionid property.
     * 
     * @return
     *     possible object is
     *     {@link REGIONID_Type }
     *     
     */
    public REGIONID_Type getREGIONID() {
        return regionid;
    }

    /**
     * Sets the value of the regionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link REGIONID_Type }
     *     
     */
    public void setREGIONID(REGIONID_Type value) {
        this.regionid = value;
    }

    /**
     * Gets the value of the dayofyear property.
     * 
     */
    public long getDAYOFYEAR() {
        return dayofyear;
    }

    /**
     * Sets the value of the dayofyear property.
     * 
     */
    public void setDAYOFYEAR(long value) {
        this.dayofyear = value;
    }

}
